
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/tf2tensorrt/utils/trt_engine_instance.proto', package='tensorflow.tensorrt', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n?tensorflow/compiler/tf2tensorrt/utils/trt_engine_instance.proto\x12\x13tensorflow.tensorrt\x1a,tensorflow/core/framework/tensor_shape.proto"b\n\x11TRTEngineInstance\x122\n\x0cinput_shapes\x18\x01 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x19\n\x11serialized_engine\x18\x02 \x01(\x0cb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR])
_TRTENGINEINSTANCE = _descriptor.Descriptor(name='TRTEngineInstance', full_name='tensorflow.tensorrt.TRTEngineInstance', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_shapes', full_name='tensorflow.tensorrt.TRTEngineInstance.input_shapes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='serialized_engine', full_name='tensorflow.tensorrt.TRTEngineInstance.serialized_engine', index=1, number=2, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=134, serialized_end=232)
_TRTENGINEINSTANCE.fields_by_name['input_shapes'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
DESCRIPTOR.message_types_by_name['TRTEngineInstance'] = _TRTENGINEINSTANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TRTEngineInstance = _reflection.GeneratedProtocolMessageType('TRTEngineInstance', (_message.Message,), {'DESCRIPTOR': _TRTENGINEINSTANCE, '__module__': 'tensorflow.compiler.tf2tensorrt.utils.trt_engine_instance_pb2'})
_sym_db.RegisterMessage(TRTEngineInstance)



from . import core

class Iterator:
  def valid(self) -> bool:
    """An iterator is either positioned at a key/value pair, or
    not valid.  This method returns true iff the iterator is valid."""
    raise NotImplementedError()

  def seek_to_first(self):
    """Position at the first key in the source.The iterator is Valid()
    after this call iff the source is not empty."""
    raise NotImplementedError()

  def seek(self, target: core.StringPiece):
    """Position at the first key in the source that is at or past target.
    The iterator is Valid() after this call iff the source contains
    an entry that comes at or past target."""
    raise NotImplementedError()

  def next(self):
    """Moves to the next entry in the source.  After this call, Valid() is
    true iff the iterator was not positioned at the last entry in the source.
    REQUIRES: Valid()"""
    raise NotImplementedError()

  def key(self) -> core.StringPiece:
    """Return the key for the current entry.  The underlying storage for
    the returned slice is valid only until the next modification of
    the iterator.
    REQUIRES: Valid()"""
    raise NotImplementedError()

  def value(self) -> core.StringPiece:
    """Return the value for the current entry.  The underlying storage for
    the returned slice is valid only until the next modification of
    the iterator.
    REQUIRES: Valid()"""
    raise NotImplementedError()

  def status(self):
    """If an error has occurred, raise it"""


class EmptyIterator(Iterator):
  def __init__(self, status = None):
    self._status = status

  def valid(self):
    return False

  def seek(self, target: core.StringPiece):
    pass

  def seek_to_first(self):
    pass

  def next(self):
    assert False

  def key(self) -> core.StringPiece:
    assert False
    return core.StringPiece()

  def value(self) -> core.StringPiece:
    assert False
    return core.StringPiece()

def status(self):
  if self._status is not None:
    raise self._status

def new_empty_iterator() -> Iterator:
  return EmptyIterator()

def new_error_iterator(status) -> Iterator:
  return EmptyIterator(status)



'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/kernel_def.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0fKernelDefProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/kernel_def_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/framework/kernel_def.proto\x12\ntensorflow\x1a*tensorflow/core/framework/attr_value.proto"\xef\x01\n\tKernelDef\x12\n\n\x02op\x18\x01 \x01(\t\x12\x13\n\x0bdevice_type\x18\x02 \x01(\t\x128\n\nconstraint\x18\x03 \x03(\x0b2$.tensorflow.KernelDef.AttrConstraint\x12\x17\n\x0fhost_memory_arg\x18\x04 \x03(\t\x12\r\n\x05label\x18\x05 \x01(\t\x12\x10\n\x08priority\x18\x06 \x01(\x05\x1aM\n\x0eAttrConstraint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x0eallowed_values\x18\x02 \x01(\x0b2\x15.tensorflow.AttrValue"3\n\nKernelList\x12%\n\x06kernel\x18\x01 \x03(\x0b2\x15.tensorflow.KernelDefB\x83\x01\n\x18org.tensorflow.frameworkB\x0fKernelDefProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/kernel_def_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR])
_KERNELDEF_ATTRCONSTRAINT = _descriptor.Descriptor(name='AttrConstraint', full_name='tensorflow.KernelDef.AttrConstraint', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.KernelDef.AttrConstraint.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allowed_values', full_name='tensorflow.KernelDef.AttrConstraint.allowed_values', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=265, serialized_end=342)
_KERNELDEF = _descriptor.Descriptor(name='KernelDef', full_name='tensorflow.KernelDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op', full_name='tensorflow.KernelDef.op', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.KernelDef.device_type', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='constraint', full_name='tensorflow.KernelDef.constraint', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_memory_arg', full_name='tensorflow.KernelDef.host_memory_arg', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='label', full_name='tensorflow.KernelDef.label', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='priority', full_name='tensorflow.KernelDef.priority', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_KERNELDEF_ATTRCONSTRAINT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=103, serialized_end=342)
_KERNELLIST = _descriptor.Descriptor(name='KernelList', full_name='tensorflow.KernelList', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kernel', full_name='tensorflow.KernelList.kernel', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=344, serialized_end=395)
_KERNELDEF_ATTRCONSTRAINT.fields_by_name['allowed_values'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._ATTRVALUE
_KERNELDEF_ATTRCONSTRAINT.containing_type = _KERNELDEF
_KERNELDEF.fields_by_name['constraint'].message_type = _KERNELDEF_ATTRCONSTRAINT
_KERNELLIST.fields_by_name['kernel'].message_type = _KERNELDEF
DESCRIPTOR.message_types_by_name['KernelDef'] = _KERNELDEF
DESCRIPTOR.message_types_by_name['KernelList'] = _KERNELLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
KernelDef = _reflection.GeneratedProtocolMessageType('KernelDef', (_message.Message,), {'AttrConstraint': _reflection.GeneratedProtocolMessageType('AttrConstraint', (_message.Message,), {'DESCRIPTOR': _KERNELDEF_ATTRCONSTRAINT, '__module__': 'tensorflow.core.framework.kernel_def_pb2'}), 'DESCRIPTOR': _KERNELDEF, '__module__': 'tensorflow.core.framework.kernel_def_pb2'})
_sym_db.RegisterMessage(KernelDef)
_sym_db.RegisterMessage(KernelDef.AttrConstraint)
KernelList = _reflection.GeneratedProtocolMessageType('KernelList', (_message.Message,), {'DESCRIPTOR': _KERNELLIST, '__module__': 'tensorflow.core.framework.kernel_def_pb2'})
_sym_db.RegisterMessage(KernelList)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/tf_function.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n3tensorflow/core/profiler/protobuf/tf_function.proto\x12\x13tensorflow.profiler"8\n\x11TfFunctionMetrics\x12\r\n\x05count\x18\x01 \x01(\x04\x12\x14\n\x0cself_time_ps\x18\x02 \x01(\x04"\x9b\x02\n\nTfFunction\x12=\n\x07metrics\x18\x01 \x03(\x0b2,.tensorflow.profiler.TfFunction.MetricsEntry\x12\x1b\n\x13total_tracing_count\x18\x02 \x01(\x03\x129\n\x08compiler\x18\x03 \x01(\x0e2\'.tensorflow.profiler.TfFunctionCompiler\x12\x1e\n\x16expensive_call_percent\x18\x04 \x01(\x01\x1aV\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x125\n\x05value\x18\x02 \x01(\x0b2&.tensorflow.profiler.TfFunctionMetrics:\x028\x01"\xad\x01\n\x0cTfFunctionDb\x12H\n\x0ctf_functions\x18\x01 \x03(\x0b22.tensorflow.profiler.TfFunctionDb.TfFunctionsEntry\x1aS\n\x10TfFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b2\x1f.tensorflow.profiler.TfFunction:\x028\x01*t\n\x17TfFunctionExecutionMode\x12\x10\n\x0cINVALID_MODE\x10\x00\x12\x0e\n\nEAGER_MODE\x10\x01\x12\x0f\n\x0bTRACED_MODE\x10\x02\x12\x13\n\x0fNOT_TRACED_MODE\x10\x03\x12\x11\n\rCONCRETE_MODE\x10\x04*w\n\x12TfFunctionCompiler\x12\x14\n\x10INVALID_COMPILER\x10\x00\x12\x12\n\x0eOTHER_COMPILER\x10\x01\x12\x12\n\x0eMIXED_COMPILER\x10\x02\x12\x10\n\x0cXLA_COMPILER\x10\x03\x12\x11\n\rMLIR_COMPILER\x10\x04b\x06proto3')
_TFFUNCTIONEXECUTIONMODE = _descriptor.EnumDescriptor(name='TfFunctionExecutionMode', full_name='tensorflow.profiler.TfFunctionExecutionMode', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID_MODE', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EAGER_MODE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TRACED_MODE', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='NOT_TRACED_MODE', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='CONCRETE_MODE', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=596, serialized_end=712)
_sym_db.RegisterEnumDescriptor(_TFFUNCTIONEXECUTIONMODE)
TfFunctionExecutionMode = enum_type_wrapper.EnumTypeWrapper(_TFFUNCTIONEXECUTIONMODE)
_TFFUNCTIONCOMPILER = _descriptor.EnumDescriptor(name='TfFunctionCompiler', full_name='tensorflow.profiler.TfFunctionCompiler', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID_COMPILER', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='OTHER_COMPILER', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='MIXED_COMPILER', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='XLA_COMPILER', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='MLIR_COMPILER', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=714, serialized_end=833)
_sym_db.RegisterEnumDescriptor(_TFFUNCTIONCOMPILER)
TfFunctionCompiler = enum_type_wrapper.EnumTypeWrapper(_TFFUNCTIONCOMPILER)
INVALID_MODE = 0
EAGER_MODE = 1
TRACED_MODE = 2
NOT_TRACED_MODE = 3
CONCRETE_MODE = 4
INVALID_COMPILER = 0
OTHER_COMPILER = 1
MIXED_COMPILER = 2
XLA_COMPILER = 3
MLIR_COMPILER = 4
_TFFUNCTIONMETRICS = _descriptor.Descriptor(name='TfFunctionMetrics', full_name='tensorflow.profiler.TfFunctionMetrics', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='count', full_name='tensorflow.profiler.TfFunctionMetrics.count', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_ps', full_name='tensorflow.profiler.TfFunctionMetrics.self_time_ps', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=76, serialized_end=132)
_TFFUNCTION_METRICSENTRY = _descriptor.Descriptor(name='MetricsEntry', full_name='tensorflow.profiler.TfFunction.MetricsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.TfFunction.MetricsEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.TfFunction.MetricsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=332, serialized_end=418)
_TFFUNCTION = _descriptor.Descriptor(name='TfFunction', full_name='tensorflow.profiler.TfFunction', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metrics', full_name='tensorflow.profiler.TfFunction.metrics', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_tracing_count', full_name='tensorflow.profiler.TfFunction.total_tracing_count', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compiler', full_name='tensorflow.profiler.TfFunction.compiler', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='expensive_call_percent', full_name='tensorflow.profiler.TfFunction.expensive_call_percent', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TFFUNCTION_METRICSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=135, serialized_end=418)
_TFFUNCTIONDB_TFFUNCTIONSENTRY = _descriptor.Descriptor(name='TfFunctionsEntry', full_name='tensorflow.profiler.TfFunctionDb.TfFunctionsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.TfFunctionDb.TfFunctionsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.TfFunctionDb.TfFunctionsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=511, serialized_end=594)
_TFFUNCTIONDB = _descriptor.Descriptor(name='TfFunctionDb', full_name='tensorflow.profiler.TfFunctionDb', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tf_functions', full_name='tensorflow.profiler.TfFunctionDb.tf_functions', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TFFUNCTIONDB_TFFUNCTIONSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=421, serialized_end=594)
_TFFUNCTION_METRICSENTRY.fields_by_name['value'].message_type = _TFFUNCTIONMETRICS
_TFFUNCTION_METRICSENTRY.containing_type = _TFFUNCTION
_TFFUNCTION.fields_by_name['metrics'].message_type = _TFFUNCTION_METRICSENTRY
_TFFUNCTION.fields_by_name['compiler'].enum_type = _TFFUNCTIONCOMPILER
_TFFUNCTIONDB_TFFUNCTIONSENTRY.fields_by_name['value'].message_type = _TFFUNCTION
_TFFUNCTIONDB_TFFUNCTIONSENTRY.containing_type = _TFFUNCTIONDB
_TFFUNCTIONDB.fields_by_name['tf_functions'].message_type = _TFFUNCTIONDB_TFFUNCTIONSENTRY
DESCRIPTOR.message_types_by_name['TfFunctionMetrics'] = _TFFUNCTIONMETRICS
DESCRIPTOR.message_types_by_name['TfFunction'] = _TFFUNCTION
DESCRIPTOR.message_types_by_name['TfFunctionDb'] = _TFFUNCTIONDB
DESCRIPTOR.enum_types_by_name['TfFunctionExecutionMode'] = _TFFUNCTIONEXECUTIONMODE
DESCRIPTOR.enum_types_by_name['TfFunctionCompiler'] = _TFFUNCTIONCOMPILER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TfFunctionMetrics = _reflection.GeneratedProtocolMessageType('TfFunctionMetrics', (_message.Message,), {'DESCRIPTOR': _TFFUNCTIONMETRICS, '__module__': 'tensorflow.core.profiler.protobuf.tf_function_pb2'})
_sym_db.RegisterMessage(TfFunctionMetrics)
TfFunction = _reflection.GeneratedProtocolMessageType('TfFunction', (_message.Message,), {'MetricsEntry': _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {'DESCRIPTOR': _TFFUNCTION_METRICSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_function_pb2'}), 'DESCRIPTOR': _TFFUNCTION, '__module__': 'tensorflow.core.profiler.protobuf.tf_function_pb2'})
_sym_db.RegisterMessage(TfFunction)
_sym_db.RegisterMessage(TfFunction.MetricsEntry)
TfFunctionDb = _reflection.GeneratedProtocolMessageType('TfFunctionDb', (_message.Message,), {'TfFunctionsEntry': _reflection.GeneratedProtocolMessageType('TfFunctionsEntry', (_message.Message,), {'DESCRIPTOR': _TFFUNCTIONDB_TFFUNCTIONSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_function_pb2'}), 'DESCRIPTOR': _TFFUNCTIONDB, '__module__': 'tensorflow.core.profiler.protobuf.tf_function_pb2'})
_sym_db.RegisterMessage(TfFunctionDb)
_sym_db.RegisterMessage(TfFunctionDb.TfFunctionsEntry)
_TFFUNCTION_METRICSENTRY._options = None
_TFFUNCTIONDB_TFFUNCTIONSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/util/test_log.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x1borg.tensorflow.util.testlogB\rTestLogProtosP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n#tensorflow/core/util/test_log.proto\x12\ntensorflow\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto"D\n\nEntryValue\x12\x16\n\x0cdouble_value\x18\x01 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00B\x06\n\x04kind"\x8c\x01\n\x0bMetricEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12/\n\tmin_value\x18\x03 \x01(\x0b2\x1c.google.protobuf.DoubleValue\x12/\n\tmax_value\x18\x04 \x01(\x0b2\x1c.google.protobuf.DoubleValue"\x8f\x02\n\x0eBenchmarkEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05iters\x18\x02 \x01(\x03\x12\x10\n\x08cpu_time\x18\x03 \x01(\x01\x12\x11\n\twall_time\x18\x04 \x01(\x01\x12\x12\n\nthroughput\x18\x05 \x01(\x01\x126\n\x06extras\x18\x06 \x03(\x0b2&.tensorflow.BenchmarkEntry.ExtrasEntry\x12(\n\x07metrics\x18\x07 \x03(\x0b2\x17.tensorflow.MetricEntry\x1aE\n\x0bExtrasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b2\x16.tensorflow.EntryValue:\x028\x01"=\n\x10BenchmarkEntries\x12)\n\x05entry\x18\x01 \x03(\x0b2\x1a.tensorflow.BenchmarkEntry"B\n\x12BuildConfiguration\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12\x10\n\x08cc_flags\x18\x02 \x03(\t\x12\x0c\n\x04opts\x18\x03 \x03(\t"f\n\x08CommitId\x12\x14\n\nchangelist\x18\x01 \x01(\x03H\x00\x12\x0e\n\x04hash\x18\x02 \x01(\tH\x00\x12\x10\n\x08snapshot\x18\x03 \x01(\t\x12\x1a\n\x12pending_changelist\x18\x04 \x01(\x03B\x06\n\x04kind"\xde\x01\n\x07CPUInfo\x12\x11\n\tnum_cores\x18\x01 \x01(\x03\x12\x19\n\x11num_cores_allowed\x18\x02 \x01(\x03\x12\x13\n\x0bmhz_per_cpu\x18\x03 \x01(\x01\x12\x10\n\x08cpu_info\x18\x04 \x01(\t\x12\x14\n\x0ccpu_governor\x18\x05 \x01(\t\x126\n\ncache_size\x18\x06 \x03(\x0b2".tensorflow.CPUInfo.CacheSizeEntry\x1a0\n\x0eCacheSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x028\x01".\n\nMemoryInfo\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x11\n\tavailable\x18\x02 \x01(\x03"6\n\x07GPUInfo\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0e\n\x06bus_id\x18\x03 \x01(\t"p\n\x0cPlatformInfo\x12\x0c\n\x04bits\x18\x01 \x01(\t\x12\x0f\n\x07linkage\x18\x02 \x01(\t\x12\x0f\n\x07machine\x18\x03 \x01(\t\x12\x0f\n\x07release\x18\x04 \x01(\t\x12\x0e\n\x06system\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t"e\n\x13AvailableDeviceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x14\n\x0cmemory_limit\x18\x03 \x01(\x03\x12\x1c\n\x14physical_description\x18\x04 \x01(\t"\xb3\x02\n\x14MachineConfiguration\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x19\n\x11serial_identifier\x18\x07 \x01(\t\x12/\n\rplatform_info\x18\x02 \x01(\x0b2\x18.tensorflow.PlatformInfo\x12%\n\x08cpu_info\x18\x03 \x01(\x0b2\x13.tensorflow.CPUInfo\x12)\n\x0bdevice_info\x18\x04 \x03(\x0b2\x14.google.protobuf.Any\x12>\n\x15available_device_info\x18\x05 \x03(\x0b2\x1f.tensorflow.AvailableDeviceInfo\x12+\n\x0bmemory_info\x18\x06 \x01(\x0b2\x16.tensorflow.MemoryInfo"\x91\x01\n\x10RunConfiguration\x12\x10\n\x08argument\x18\x01 \x03(\t\x12;\n\x08env_vars\x18\x02 \x03(\x0b2).tensorflow.RunConfiguration.EnvVarsEntry\x1a.\n\x0cEnvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"\xd0\x04\n\x0bTestResults\x12\x0e\n\x06target\x18\x01 \x01(\t\x12-\n\x07entries\x18\x02 \x01(\x0b2\x1c.tensorflow.BenchmarkEntries\x12;\n\x13build_configuration\x18\x03 \x01(\x0b2\x1e.tensorflow.BuildConfiguration\x12\'\n\tcommit_id\x18\x04 \x01(\x0b2\x14.tensorflow.CommitId\x12\x12\n\nstart_time\x18\x05 \x01(\x03\x12\x10\n\x08run_time\x18\x06 \x01(\x01\x12?\n\x15machine_configuration\x18\x07 \x01(\x0b2 .tensorflow.MachineConfiguration\x127\n\x11run_configuration\x18\x08 \x01(\x0b2\x1c.tensorflow.RunConfiguration\x12\x0c\n\x04name\x18\t \x01(\t\x12=\n\x0ebenchmark_type\x18\n \x01(\x0e2%.tensorflow.TestResults.BenchmarkType\x12\x10\n\x08run_mode\x18\x0b \x01(\t\x12\x12\n\ntf_version\x18\x0c \x01(\t"\x88\x01\n\rBenchmarkType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12CPP_MICROBENCHMARK\x10\x01\x12\x14\n\x10PYTHON_BENCHMARK\x10\x02\x12\x15\n\x11ANDROID_BENCHMARK\x10\x03\x12\x12\n\x0eEDGE_BENCHMARK\x10\x04\x12\x11\n\rIOS_BENCHMARK\x10\x05B1\n\x1borg.tensorflow.util.testlogB\rTestLogProtosP\x01\xf8\x01\x01b\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR])
_TESTRESULTS_BENCHMARKTYPE = _descriptor.EnumDescriptor(name='BenchmarkType', full_name='tensorflow.TestResults.BenchmarkType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='CPP_MICROBENCHMARK', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='PYTHON_BENCHMARK', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ANDROID_BENCHMARK', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EDGE_BENCHMARK', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='IOS_BENCHMARK', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=2293, serialized_end=2429)
_sym_db.RegisterEnumDescriptor(_TESTRESULTS_BENCHMARKTYPE)
_ENTRYVALUE = _descriptor.Descriptor(name='EntryValue', full_name='tensorflow.EntryValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='double_value', full_name='tensorflow.EntryValue.double_value', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='string_value', full_name='tensorflow.EntryValue.string_value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='kind', full_name='tensorflow.EntryValue.kind', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=110, serialized_end=178)
_METRICENTRY = _descriptor.Descriptor(name='MetricEntry', full_name='tensorflow.MetricEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.MetricEntry.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.MetricEntry.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='min_value', full_name='tensorflow.MetricEntry.min_value', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_value', full_name='tensorflow.MetricEntry.max_value', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=181, serialized_end=321)
_BENCHMARKENTRY_EXTRASENTRY = _descriptor.Descriptor(name='ExtrasEntry', full_name='tensorflow.BenchmarkEntry.ExtrasEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.BenchmarkEntry.ExtrasEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.BenchmarkEntry.ExtrasEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=526, serialized_end=595)
_BENCHMARKENTRY = _descriptor.Descriptor(name='BenchmarkEntry', full_name='tensorflow.BenchmarkEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.BenchmarkEntry.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='iters', full_name='tensorflow.BenchmarkEntry.iters', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_time', full_name='tensorflow.BenchmarkEntry.cpu_time', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='wall_time', full_name='tensorflow.BenchmarkEntry.wall_time', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='throughput', full_name='tensorflow.BenchmarkEntry.throughput', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extras', full_name='tensorflow.BenchmarkEntry.extras', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metrics', full_name='tensorflow.BenchmarkEntry.metrics', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_BENCHMARKENTRY_EXTRASENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=324, serialized_end=595)
_BENCHMARKENTRIES = _descriptor.Descriptor(name='BenchmarkEntries', full_name='tensorflow.BenchmarkEntries', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entry', full_name='tensorflow.BenchmarkEntries.entry', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=597, serialized_end=658)
_BUILDCONFIGURATION = _descriptor.Descriptor(name='BuildConfiguration', full_name='tensorflow.BuildConfiguration', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='mode', full_name='tensorflow.BuildConfiguration.mode', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cc_flags', full_name='tensorflow.BuildConfiguration.cc_flags', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='opts', full_name='tensorflow.BuildConfiguration.opts', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=660, serialized_end=726)
_COMMITID = _descriptor.Descriptor(name='CommitId', full_name='tensorflow.CommitId', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='changelist', full_name='tensorflow.CommitId.changelist', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hash', full_name='tensorflow.CommitId.hash', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='snapshot', full_name='tensorflow.CommitId.snapshot', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pending_changelist', full_name='tensorflow.CommitId.pending_changelist', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='kind', full_name='tensorflow.CommitId.kind', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=728, serialized_end=830)
_CPUINFO_CACHESIZEENTRY = _descriptor.Descriptor(name='CacheSizeEntry', full_name='tensorflow.CPUInfo.CacheSizeEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.CPUInfo.CacheSizeEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.CPUInfo.CacheSizeEntry.value', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1007, serialized_end=1055)
_CPUINFO = _descriptor.Descriptor(name='CPUInfo', full_name='tensorflow.CPUInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_cores', full_name='tensorflow.CPUInfo.num_cores', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_allowed', full_name='tensorflow.CPUInfo.num_cores_allowed', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mhz_per_cpu', full_name='tensorflow.CPUInfo.mhz_per_cpu', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_info', full_name='tensorflow.CPUInfo.cpu_info', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_governor', full_name='tensorflow.CPUInfo.cpu_governor', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cache_size', full_name='tensorflow.CPUInfo.cache_size', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_CPUINFO_CACHESIZEENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=833, serialized_end=1055)
_MEMORYINFO = _descriptor.Descriptor(name='MemoryInfo', full_name='tensorflow.MemoryInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='total', full_name='tensorflow.MemoryInfo.total', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='available', full_name='tensorflow.MemoryInfo.available', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1057, serialized_end=1103)
_GPUINFO = _descriptor.Descriptor(name='GPUInfo', full_name='tensorflow.GPUInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='model', full_name='tensorflow.GPUInfo.model', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uuid', full_name='tensorflow.GPUInfo.uuid', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bus_id', full_name='tensorflow.GPUInfo.bus_id', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1105, serialized_end=1159)
_PLATFORMINFO = _descriptor.Descriptor(name='PlatformInfo', full_name='tensorflow.PlatformInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bits', full_name='tensorflow.PlatformInfo.bits', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='linkage', full_name='tensorflow.PlatformInfo.linkage', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='machine', full_name='tensorflow.PlatformInfo.machine', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release', full_name='tensorflow.PlatformInfo.release', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='system', full_name='tensorflow.PlatformInfo.system', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version', full_name='tensorflow.PlatformInfo.version', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1161, serialized_end=1273)
_AVAILABLEDEVICEINFO = _descriptor.Descriptor(name='AvailableDeviceInfo', full_name='tensorflow.AvailableDeviceInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.AvailableDeviceInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.AvailableDeviceInfo.type', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_limit', full_name='tensorflow.AvailableDeviceInfo.memory_limit', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='physical_description', full_name='tensorflow.AvailableDeviceInfo.physical_description', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1275, serialized_end=1376)
_MACHINECONFIGURATION = _descriptor.Descriptor(name='MachineConfiguration', full_name='tensorflow.MachineConfiguration', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hostname', full_name='tensorflow.MachineConfiguration.hostname', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='serial_identifier', full_name='tensorflow.MachineConfiguration.serial_identifier', index=1, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='platform_info', full_name='tensorflow.MachineConfiguration.platform_info', index=2, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_info', full_name='tensorflow.MachineConfiguration.cpu_info', index=3, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_info', full_name='tensorflow.MachineConfiguration.device_info', index=4, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='available_device_info', full_name='tensorflow.MachineConfiguration.available_device_info', index=5, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_info', full_name='tensorflow.MachineConfiguration.memory_info', index=6, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1379, serialized_end=1686)
_RUNCONFIGURATION_ENVVARSENTRY = _descriptor.Descriptor(name='EnvVarsEntry', full_name='tensorflow.RunConfiguration.EnvVarsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.RunConfiguration.EnvVarsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.RunConfiguration.EnvVarsEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1788, serialized_end=1834)
_RUNCONFIGURATION = _descriptor.Descriptor(name='RunConfiguration', full_name='tensorflow.RunConfiguration', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='argument', full_name='tensorflow.RunConfiguration.argument', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='env_vars', full_name='tensorflow.RunConfiguration.env_vars', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_RUNCONFIGURATION_ENVVARSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1689, serialized_end=1834)
_TESTRESULTS = _descriptor.Descriptor(name='TestResults', full_name='tensorflow.TestResults', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target', full_name='tensorflow.TestResults.target', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='entries', full_name='tensorflow.TestResults.entries', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_configuration', full_name='tensorflow.TestResults.build_configuration', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='commit_id', full_name='tensorflow.TestResults.commit_id', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time', full_name='tensorflow.TestResults.start_time', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_time', full_name='tensorflow.TestResults.run_time', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='machine_configuration', full_name='tensorflow.TestResults.machine_configuration', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_configuration', full_name='tensorflow.TestResults.run_configuration', index=7, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.TestResults.name', index=8, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='benchmark_type', full_name='tensorflow.TestResults.benchmark_type', index=9, number=10, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_mode', full_name='tensorflow.TestResults.run_mode', index=10, number=11, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_version', full_name='tensorflow.TestResults.tf_version', index=11, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_TESTRESULTS_BENCHMARKTYPE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1837, serialized_end=2429)
_ENTRYVALUE.oneofs_by_name['kind'].fields.append(_ENTRYVALUE.fields_by_name['double_value'])
_ENTRYVALUE.fields_by_name['double_value'].containing_oneof = _ENTRYVALUE.oneofs_by_name['kind']
_ENTRYVALUE.oneofs_by_name['kind'].fields.append(_ENTRYVALUE.fields_by_name['string_value'])
_ENTRYVALUE.fields_by_name['string_value'].containing_oneof = _ENTRYVALUE.oneofs_by_name['kind']
_METRICENTRY.fields_by_name['min_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_METRICENTRY.fields_by_name['max_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_BENCHMARKENTRY_EXTRASENTRY.fields_by_name['value'].message_type = _ENTRYVALUE
_BENCHMARKENTRY_EXTRASENTRY.containing_type = _BENCHMARKENTRY
_BENCHMARKENTRY.fields_by_name['extras'].message_type = _BENCHMARKENTRY_EXTRASENTRY
_BENCHMARKENTRY.fields_by_name['metrics'].message_type = _METRICENTRY
_BENCHMARKENTRIES.fields_by_name['entry'].message_type = _BENCHMARKENTRY
_COMMITID.oneofs_by_name['kind'].fields.append(_COMMITID.fields_by_name['changelist'])
_COMMITID.fields_by_name['changelist'].containing_oneof = _COMMITID.oneofs_by_name['kind']
_COMMITID.oneofs_by_name['kind'].fields.append(_COMMITID.fields_by_name['hash'])
_COMMITID.fields_by_name['hash'].containing_oneof = _COMMITID.oneofs_by_name['kind']
_CPUINFO_CACHESIZEENTRY.containing_type = _CPUINFO
_CPUINFO.fields_by_name['cache_size'].message_type = _CPUINFO_CACHESIZEENTRY
_MACHINECONFIGURATION.fields_by_name['platform_info'].message_type = _PLATFORMINFO
_MACHINECONFIGURATION.fields_by_name['cpu_info'].message_type = _CPUINFO
_MACHINECONFIGURATION.fields_by_name['device_info'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MACHINECONFIGURATION.fields_by_name['available_device_info'].message_type = _AVAILABLEDEVICEINFO
_MACHINECONFIGURATION.fields_by_name['memory_info'].message_type = _MEMORYINFO
_RUNCONFIGURATION_ENVVARSENTRY.containing_type = _RUNCONFIGURATION
_RUNCONFIGURATION.fields_by_name['env_vars'].message_type = _RUNCONFIGURATION_ENVVARSENTRY
_TESTRESULTS.fields_by_name['entries'].message_type = _BENCHMARKENTRIES
_TESTRESULTS.fields_by_name['build_configuration'].message_type = _BUILDCONFIGURATION
_TESTRESULTS.fields_by_name['commit_id'].message_type = _COMMITID
_TESTRESULTS.fields_by_name['machine_configuration'].message_type = _MACHINECONFIGURATION
_TESTRESULTS.fields_by_name['run_configuration'].message_type = _RUNCONFIGURATION
_TESTRESULTS.fields_by_name['benchmark_type'].enum_type = _TESTRESULTS_BENCHMARKTYPE
_TESTRESULTS_BENCHMARKTYPE.containing_type = _TESTRESULTS
DESCRIPTOR.message_types_by_name['EntryValue'] = _ENTRYVALUE
DESCRIPTOR.message_types_by_name['MetricEntry'] = _METRICENTRY
DESCRIPTOR.message_types_by_name['BenchmarkEntry'] = _BENCHMARKENTRY
DESCRIPTOR.message_types_by_name['BenchmarkEntries'] = _BENCHMARKENTRIES
DESCRIPTOR.message_types_by_name['BuildConfiguration'] = _BUILDCONFIGURATION
DESCRIPTOR.message_types_by_name['CommitId'] = _COMMITID
DESCRIPTOR.message_types_by_name['CPUInfo'] = _CPUINFO
DESCRIPTOR.message_types_by_name['MemoryInfo'] = _MEMORYINFO
DESCRIPTOR.message_types_by_name['GPUInfo'] = _GPUINFO
DESCRIPTOR.message_types_by_name['PlatformInfo'] = _PLATFORMINFO
DESCRIPTOR.message_types_by_name['AvailableDeviceInfo'] = _AVAILABLEDEVICEINFO
DESCRIPTOR.message_types_by_name['MachineConfiguration'] = _MACHINECONFIGURATION
DESCRIPTOR.message_types_by_name['RunConfiguration'] = _RUNCONFIGURATION
DESCRIPTOR.message_types_by_name['TestResults'] = _TESTRESULTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
EntryValue = _reflection.GeneratedProtocolMessageType('EntryValue', (_message.Message,), {'DESCRIPTOR': _ENTRYVALUE, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(EntryValue)
MetricEntry = _reflection.GeneratedProtocolMessageType('MetricEntry', (_message.Message,), {'DESCRIPTOR': _METRICENTRY, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(MetricEntry)
BenchmarkEntry = _reflection.GeneratedProtocolMessageType('BenchmarkEntry', (_message.Message,), {'ExtrasEntry': _reflection.GeneratedProtocolMessageType('ExtrasEntry', (_message.Message,), {'DESCRIPTOR': _BENCHMARKENTRY_EXTRASENTRY, '__module__': 'tensorflow.core.util.test_log_pb2'}), 'DESCRIPTOR': _BENCHMARKENTRY, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(BenchmarkEntry)
_sym_db.RegisterMessage(BenchmarkEntry.ExtrasEntry)
BenchmarkEntries = _reflection.GeneratedProtocolMessageType('BenchmarkEntries', (_message.Message,), {'DESCRIPTOR': _BENCHMARKENTRIES, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(BenchmarkEntries)
BuildConfiguration = _reflection.GeneratedProtocolMessageType('BuildConfiguration', (_message.Message,), {'DESCRIPTOR': _BUILDCONFIGURATION, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(BuildConfiguration)
CommitId = _reflection.GeneratedProtocolMessageType('CommitId', (_message.Message,), {'DESCRIPTOR': _COMMITID, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(CommitId)
CPUInfo = _reflection.GeneratedProtocolMessageType('CPUInfo', (_message.Message,), {'CacheSizeEntry': _reflection.GeneratedProtocolMessageType('CacheSizeEntry', (_message.Message,), {'DESCRIPTOR': _CPUINFO_CACHESIZEENTRY, '__module__': 'tensorflow.core.util.test_log_pb2'}), 'DESCRIPTOR': _CPUINFO, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(CPUInfo)
_sym_db.RegisterMessage(CPUInfo.CacheSizeEntry)
MemoryInfo = _reflection.GeneratedProtocolMessageType('MemoryInfo', (_message.Message,), {'DESCRIPTOR': _MEMORYINFO, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(MemoryInfo)
GPUInfo = _reflection.GeneratedProtocolMessageType('GPUInfo', (_message.Message,), {'DESCRIPTOR': _GPUINFO, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(GPUInfo)
PlatformInfo = _reflection.GeneratedProtocolMessageType('PlatformInfo', (_message.Message,), {'DESCRIPTOR': _PLATFORMINFO, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(PlatformInfo)
AvailableDeviceInfo = _reflection.GeneratedProtocolMessageType('AvailableDeviceInfo', (_message.Message,), {'DESCRIPTOR': _AVAILABLEDEVICEINFO, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(AvailableDeviceInfo)
MachineConfiguration = _reflection.GeneratedProtocolMessageType('MachineConfiguration', (_message.Message,), {'DESCRIPTOR': _MACHINECONFIGURATION, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(MachineConfiguration)
RunConfiguration = _reflection.GeneratedProtocolMessageType('RunConfiguration', (_message.Message,), {'EnvVarsEntry': _reflection.GeneratedProtocolMessageType('EnvVarsEntry', (_message.Message,), {'DESCRIPTOR': _RUNCONFIGURATION_ENVVARSENTRY, '__module__': 'tensorflow.core.util.test_log_pb2'}), 'DESCRIPTOR': _RUNCONFIGURATION, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(RunConfiguration)
_sym_db.RegisterMessage(RunConfiguration.EnvVarsEntry)
TestResults = _reflection.GeneratedProtocolMessageType('TestResults', (_message.Message,), {'DESCRIPTOR': _TESTRESULTS, '__module__': 'tensorflow.core.util.test_log_pb2'})
_sym_db.RegisterMessage(TestResults)
DESCRIPTOR._options = None
_BENCHMARKENTRY_EXTRASENTRY._options = None
_CPUINFO_CACHESIZEENTRY._options = None
_RUNCONFIGURATION_ENVVARSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import summary_pb2 as tensorflow_dot_core_dot_framework_dot_summary__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/util/event.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x13org.tensorflow.utilB\x0bEventProtosP\x01ZGgithub.com/tensorflow/tensorflow/tensorflow/go/core/util/event_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n tensorflow/core/util/event.proto\x12\ntensorflow\x1a\'tensorflow/core/framework/summary.proto"\xbf\x02\n\x05Event\x12\x11\n\twall_time\x18\x01 \x01(\x01\x12\x0c\n\x04step\x18\x02 \x01(\x03\x12\x16\n\x0cfile_version\x18\x03 \x01(\tH\x00\x12\x13\n\tgraph_def\x18\x04 \x01(\x0cH\x00\x12&\n\x07summary\x18\x05 \x01(\x0b2\x13.tensorflow.SummaryH\x00\x121\n\x0blog_message\x18\x06 \x01(\x0b2\x16.tensorflow.LogMessageB\x02\x18\x01H\x00\x12-\n\x0bsession_log\x18\x07 \x01(\x0b2\x16.tensorflow.SessionLogH\x00\x12<\n\x13tagged_run_metadata\x18\x08 \x01(\x0b2\x1d.tensorflow.TaggedRunMetadataH\x00\x12\x18\n\x0emeta_graph_def\x18\t \x01(\x0cH\x00B\x06\n\x04what"\xa1\x01\n\nLogMessage\x12+\n\x05level\x18\x01 \x01(\x0e2\x1c.tensorflow.LogMessage.Level\x12\x0f\n\x07message\x18\x02 \x01(\t"Q\n\x05Level\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tDEBUGGING\x10\n\x12\x08\n\x04INFO\x10\x14\x12\x08\n\x04WARN\x10\x1e\x12\t\n\x05ERROR\x10(\x12\t\n\x05FATAL\x102\x1a\x02\x18\x01:\x02\x18\x01"\xb6\x01\n\nSessionLog\x124\n\x06status\x18\x01 \x01(\x0e2$.tensorflow.SessionLog.SessionStatus\x12\x17\n\x0fcheckpoint_path\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t"L\n\rSessionStatus\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\t\n\x05START\x10\x01\x12\x08\n\x04STOP\x10\x02\x12\x0e\n\nCHECKPOINT\x10\x03"6\n\x11TaggedRunMetadata\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x14\n\x0crun_metadata\x18\x02 \x01(\x0c"$\n\x0eWatchdogConfig\x12\x12\n\ntimeout_ms\x18\x01 \x01(\x03"&\n\x11RequestedExitCode\x12\x11\n\texit_code\x18\x01 \x01(\x05"\xb6\x01\n\x16WorkerHeartbeatRequest\x125\n\rshutdown_mode\x18\x01 \x01(\x0e2\x1e.tensorflow.WorkerShutdownMode\x123\n\x0fwatchdog_config\x18\x02 \x01(\x0b2\x1a.tensorflow.WatchdogConfig\x120\n\texit_code\x18\x03 \x01(\x0b2\x1d.tensorflow.RequestedExitCode"\x83\x01\n\x17WorkerHeartbeatResponse\x12/\n\rhealth_status\x18\x01 \x01(\x0e2\x18.tensorflow.WorkerHealth\x12%\n\nworker_log\x18\x02 \x03(\x0b2\x11.tensorflow.Event\x12\x10\n\x08hostname\x18\x03 \x01(\t*[\n\x0cWorkerHealth\x12\x06\n\x02OK\x10\x00\x12\x1c\n\x18RECEIVED_SHUTDOWN_SIGNAL\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x11\n\rSHUTTING_DOWN\x10\x03*k\n\x12WorkerShutdownMode\x12\x0b\n\x07DEFAULT\x10\x00\x12\x12\n\x0eNOT_CONFIGURED\x10\x01\x12\x18\n\x14WAIT_FOR_COORDINATOR\x10\x02\x12\x1a\n\x16SHUTDOWN_AFTER_TIMEOUT\x10\x03Bp\n\x13org.tensorflow.utilB\x0bEventProtosP\x01ZGgithub.com/tensorflow/tensorflow/tensorflow/go/core/util/event_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_summary__pb2.DESCRIPTOR])
_WORKERHEALTH = _descriptor.EnumDescriptor(name='WorkerHealth', full_name='tensorflow.WorkerHealth', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='OK', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='RECEIVED_SHUTDOWN_SIGNAL', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INTERNAL_ERROR', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SHUTTING_DOWN', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1213, serialized_end=1304)
_sym_db.RegisterEnumDescriptor(_WORKERHEALTH)
WorkerHealth = enum_type_wrapper.EnumTypeWrapper(_WORKERHEALTH)
_WORKERSHUTDOWNMODE = _descriptor.EnumDescriptor(name='WorkerShutdownMode', full_name='tensorflow.WorkerShutdownMode', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DEFAULT', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='NOT_CONFIGURED', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='WAIT_FOR_COORDINATOR', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SHUTDOWN_AFTER_TIMEOUT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1306, serialized_end=1413)
_sym_db.RegisterEnumDescriptor(_WORKERSHUTDOWNMODE)
WorkerShutdownMode = enum_type_wrapper.EnumTypeWrapper(_WORKERSHUTDOWNMODE)
OK = 0
RECEIVED_SHUTDOWN_SIGNAL = 1
INTERNAL_ERROR = 2
SHUTTING_DOWN = 3
DEFAULT = 0
NOT_CONFIGURED = 1
WAIT_FOR_COORDINATOR = 2
SHUTDOWN_AFTER_TIMEOUT = 3
_LOGMESSAGE_LEVEL = _descriptor.EnumDescriptor(name='Level', full_name='tensorflow.LogMessage.Level', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DEBUGGING', index=1, number=10, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INFO', index=2, number=20, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='WARN', index=3, number=30, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ERROR', index=4, number=40, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='FATAL', index=5, number=50, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=b'\x18\x01', serialized_start=488, serialized_end=569)
_sym_db.RegisterEnumDescriptor(_LOGMESSAGE_LEVEL)
_SESSIONLOG_SESSIONSTATUS = _descriptor.EnumDescriptor(name='SessionStatus', full_name='tensorflow.SessionLog.SessionStatus', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='STATUS_UNSPECIFIED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='START', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='STOP', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='CHECKPOINT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=682, serialized_end=758)
_sym_db.RegisterEnumDescriptor(_SESSIONLOG_SESSIONSTATUS)
_EVENT = _descriptor.Descriptor(name='Event', full_name='tensorflow.Event', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='wall_time', full_name='tensorflow.Event.wall_time', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step', full_name='tensorflow.Event.step', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='file_version', full_name='tensorflow.Event.file_version', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_def', full_name='tensorflow.Event.graph_def', index=3, number=4, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary', full_name='tensorflow.Event.summary', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='log_message', full_name='tensorflow.Event.log_message', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_log', full_name='tensorflow.Event.session_log', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tagged_run_metadata', full_name='tensorflow.Event.tagged_run_metadata', index=7, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='meta_graph_def', full_name='tensorflow.Event.meta_graph_def', index=8, number=9, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='what', full_name='tensorflow.Event.what', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=90, serialized_end=409)
_LOGMESSAGE = _descriptor.Descriptor(name='LogMessage', full_name='tensorflow.LogMessage', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='level', full_name='tensorflow.LogMessage.level', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='message', full_name='tensorflow.LogMessage.message', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_LOGMESSAGE_LEVEL], serialized_options=b'\x18\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=412, serialized_end=573)
_SESSIONLOG = _descriptor.Descriptor(name='SessionLog', full_name='tensorflow.SessionLog', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='status', full_name='tensorflow.SessionLog.status', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='checkpoint_path', full_name='tensorflow.SessionLog.checkpoint_path', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='msg', full_name='tensorflow.SessionLog.msg', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_SESSIONLOG_SESSIONSTATUS], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=576, serialized_end=758)
_TAGGEDRUNMETADATA = _descriptor.Descriptor(name='TaggedRunMetadata', full_name='tensorflow.TaggedRunMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tag', full_name='tensorflow.TaggedRunMetadata.tag', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_metadata', full_name='tensorflow.TaggedRunMetadata.run_metadata', index=1, number=2, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=760, serialized_end=814)
_WATCHDOGCONFIG = _descriptor.Descriptor(name='WatchdogConfig', full_name='tensorflow.WatchdogConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='timeout_ms', full_name='tensorflow.WatchdogConfig.timeout_ms', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=816, serialized_end=852)
_REQUESTEDEXITCODE = _descriptor.Descriptor(name='RequestedExitCode', full_name='tensorflow.RequestedExitCode', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='exit_code', full_name='tensorflow.RequestedExitCode.exit_code', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=854, serialized_end=892)
_WORKERHEARTBEATREQUEST = _descriptor.Descriptor(name='WorkerHeartbeatRequest', full_name='tensorflow.WorkerHeartbeatRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='shutdown_mode', full_name='tensorflow.WorkerHeartbeatRequest.shutdown_mode', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='watchdog_config', full_name='tensorflow.WorkerHeartbeatRequest.watchdog_config', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='exit_code', full_name='tensorflow.WorkerHeartbeatRequest.exit_code', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=895, serialized_end=1077)
_WORKERHEARTBEATRESPONSE = _descriptor.Descriptor(name='WorkerHeartbeatResponse', full_name='tensorflow.WorkerHeartbeatResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='health_status', full_name='tensorflow.WorkerHeartbeatResponse.health_status', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='worker_log', full_name='tensorflow.WorkerHeartbeatResponse.worker_log', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hostname', full_name='tensorflow.WorkerHeartbeatResponse.hostname', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1080, serialized_end=1211)
_EVENT.fields_by_name['summary'].message_type = tensorflow_dot_core_dot_framework_dot_summary__pb2._SUMMARY
_EVENT.fields_by_name['log_message'].message_type = _LOGMESSAGE
_EVENT.fields_by_name['session_log'].message_type = _SESSIONLOG
_EVENT.fields_by_name['tagged_run_metadata'].message_type = _TAGGEDRUNMETADATA
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['file_version'])
_EVENT.fields_by_name['file_version'].containing_oneof = _EVENT.oneofs_by_name['what']
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['graph_def'])
_EVENT.fields_by_name['graph_def'].containing_oneof = _EVENT.oneofs_by_name['what']
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['summary'])
_EVENT.fields_by_name['summary'].containing_oneof = _EVENT.oneofs_by_name['what']
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['log_message'])
_EVENT.fields_by_name['log_message'].containing_oneof = _EVENT.oneofs_by_name['what']
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['session_log'])
_EVENT.fields_by_name['session_log'].containing_oneof = _EVENT.oneofs_by_name['what']
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['tagged_run_metadata'])
_EVENT.fields_by_name['tagged_run_metadata'].containing_oneof = _EVENT.oneofs_by_name['what']
_EVENT.oneofs_by_name['what'].fields.append(_EVENT.fields_by_name['meta_graph_def'])
_EVENT.fields_by_name['meta_graph_def'].containing_oneof = _EVENT.oneofs_by_name['what']
_LOGMESSAGE.fields_by_name['level'].enum_type = _LOGMESSAGE_LEVEL
_LOGMESSAGE_LEVEL.containing_type = _LOGMESSAGE
_SESSIONLOG.fields_by_name['status'].enum_type = _SESSIONLOG_SESSIONSTATUS
_SESSIONLOG_SESSIONSTATUS.containing_type = _SESSIONLOG
_WORKERHEARTBEATREQUEST.fields_by_name['shutdown_mode'].enum_type = _WORKERSHUTDOWNMODE
_WORKERHEARTBEATREQUEST.fields_by_name['watchdog_config'].message_type = _WATCHDOGCONFIG
_WORKERHEARTBEATREQUEST.fields_by_name['exit_code'].message_type = _REQUESTEDEXITCODE
_WORKERHEARTBEATRESPONSE.fields_by_name['health_status'].enum_type = _WORKERHEALTH
_WORKERHEARTBEATRESPONSE.fields_by_name['worker_log'].message_type = _EVENT
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE
DESCRIPTOR.message_types_by_name['SessionLog'] = _SESSIONLOG
DESCRIPTOR.message_types_by_name['TaggedRunMetadata'] = _TAGGEDRUNMETADATA
DESCRIPTOR.message_types_by_name['WatchdogConfig'] = _WATCHDOGCONFIG
DESCRIPTOR.message_types_by_name['RequestedExitCode'] = _REQUESTEDEXITCODE
DESCRIPTOR.message_types_by_name['WorkerHeartbeatRequest'] = _WORKERHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['WorkerHeartbeatResponse'] = _WORKERHEARTBEATRESPONSE
DESCRIPTOR.enum_types_by_name['WorkerHealth'] = _WORKERHEALTH
DESCRIPTOR.enum_types_by_name['WorkerShutdownMode'] = _WORKERSHUTDOWNMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {'DESCRIPTOR': _EVENT, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(Event)
LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), {'DESCRIPTOR': _LOGMESSAGE, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(LogMessage)
SessionLog = _reflection.GeneratedProtocolMessageType('SessionLog', (_message.Message,), {'DESCRIPTOR': _SESSIONLOG, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(SessionLog)
TaggedRunMetadata = _reflection.GeneratedProtocolMessageType('TaggedRunMetadata', (_message.Message,), {'DESCRIPTOR': _TAGGEDRUNMETADATA, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(TaggedRunMetadata)
WatchdogConfig = _reflection.GeneratedProtocolMessageType('WatchdogConfig', (_message.Message,), {'DESCRIPTOR': _WATCHDOGCONFIG, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(WatchdogConfig)
RequestedExitCode = _reflection.GeneratedProtocolMessageType('RequestedExitCode', (_message.Message,), {'DESCRIPTOR': _REQUESTEDEXITCODE, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(RequestedExitCode)
WorkerHeartbeatRequest = _reflection.GeneratedProtocolMessageType('WorkerHeartbeatRequest', (_message.Message,), {'DESCRIPTOR': _WORKERHEARTBEATREQUEST, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(WorkerHeartbeatRequest)
WorkerHeartbeatResponse = _reflection.GeneratedProtocolMessageType('WorkerHeartbeatResponse', (_message.Message,), {'DESCRIPTOR': _WORKERHEARTBEATRESPONSE, '__module__': 'tensorflow.core.util.event_pb2'})
_sym_db.RegisterMessage(WorkerHeartbeatResponse)
DESCRIPTOR._options = None
_EVENT.fields_by_name['log_message']._options = None
_LOGMESSAGE_LEVEL._options = None
_LOGMESSAGE._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/mlir/lite/quantization/quantization_info.proto', package='mlir.quant', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\nBtensorflow/compiler/mlir/lite/quantization/quantization_info.proto\x12\nmlir.quant"\xd2\x04\n\x10QuantizationInfo\x129\n\x07entries\x18\x01 \x03(\x0b2(.mlir.quant.QuantizationInfo.QuantParams\x1a"\n\x06MinMax\x12\x0b\n\x03min\x18\x01 \x01(\x02\x12\x0b\n\x03max\x18\x02 \x01(\x02\x1a1\n\x0cAffineParams\x12\r\n\x05scale\x18\x01 \x01(\x02\x12\x12\n\nzero_point\x18\x02 \x01(\x05\x1a\x9b\x01\n\rPerAxisParams\x126\n\x07min_max\x18\x01 \x01(\x0b2#.mlir.quant.QuantizationInfo.MinMaxH\x00\x12B\n\raffine_params\x18\x02 \x01(\x0b2).mlir.quant.QuantizationInfo.AffineParamsH\x00B\x0e\n\x0cparams_oneof\x1aY\n\x08Metadata\x12\x10\n\x08num_bits\x18\x01 \x01(\x05\x12\x15\n\rquantize_axis\x18\x02 \x01(\x05\x12\x11\n\trange_min\x18\x03 \x01(\x05\x12\x11\n\trange_max\x18\x04 \x01(\x05\x1a\xb2\x01\n\x0bQuantParams\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\x14\n\nname_regex\x18\x02 \x01(\tH\x00\x12:\n\x06params\x18\x03 \x03(\x0b2*.mlir.quant.QuantizationInfo.PerAxisParams\x123\n\x04meta\x18\x05 \x01(\x0b2%.mlir.quant.QuantizationInfo.MetadataB\x0c\n\nname_oneofB\x03\xf8\x01\x01b\x06proto3')
_QUANTIZATIONINFO_MINMAX = _descriptor.Descriptor(name='MinMax', full_name='mlir.quant.QuantizationInfo.MinMax', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='min', full_name='mlir.quant.QuantizationInfo.MinMax.min', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max', full_name='mlir.quant.QuantizationInfo.MinMax.max', index=1, number=2, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=162, serialized_end=196)
_QUANTIZATIONINFO_AFFINEPARAMS = _descriptor.Descriptor(name='AffineParams', full_name='mlir.quant.QuantizationInfo.AffineParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='scale', full_name='mlir.quant.QuantizationInfo.AffineParams.scale', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='zero_point', full_name='mlir.quant.QuantizationInfo.AffineParams.zero_point', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=198, serialized_end=247)
_QUANTIZATIONINFO_PERAXISPARAMS = _descriptor.Descriptor(name='PerAxisParams', full_name='mlir.quant.QuantizationInfo.PerAxisParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='min_max', full_name='mlir.quant.QuantizationInfo.PerAxisParams.min_max', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='affine_params', full_name='mlir.quant.QuantizationInfo.PerAxisParams.affine_params', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params_oneof', full_name='mlir.quant.QuantizationInfo.PerAxisParams.params_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=250, serialized_end=405)
_QUANTIZATIONINFO_METADATA = _descriptor.Descriptor(name='Metadata', full_name='mlir.quant.QuantizationInfo.Metadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_bits', full_name='mlir.quant.QuantizationInfo.Metadata.num_bits', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='quantize_axis', full_name='mlir.quant.QuantizationInfo.Metadata.quantize_axis', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='range_min', full_name='mlir.quant.QuantizationInfo.Metadata.range_min', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='range_max', full_name='mlir.quant.QuantizationInfo.Metadata.range_max', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=407, serialized_end=496)
_QUANTIZATIONINFO_QUANTPARAMS = _descriptor.Descriptor(name='QuantParams', full_name='mlir.quant.QuantizationInfo.QuantParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='mlir.quant.QuantizationInfo.QuantParams.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name_regex', full_name='mlir.quant.QuantizationInfo.QuantParams.name_regex', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='params', full_name='mlir.quant.QuantizationInfo.QuantParams.params', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='meta', full_name='mlir.quant.QuantizationInfo.QuantParams.meta', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='name_oneof', full_name='mlir.quant.QuantizationInfo.QuantParams.name_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=499, serialized_end=677)
_QUANTIZATIONINFO = _descriptor.Descriptor(name='QuantizationInfo', full_name='mlir.quant.QuantizationInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entries', full_name='mlir.quant.QuantizationInfo.entries', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_QUANTIZATIONINFO_MINMAX, _QUANTIZATIONINFO_AFFINEPARAMS, _QUANTIZATIONINFO_PERAXISPARAMS, _QUANTIZATIONINFO_METADATA, _QUANTIZATIONINFO_QUANTPARAMS], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=83, serialized_end=677)
_QUANTIZATIONINFO_MINMAX.containing_type = _QUANTIZATIONINFO
_QUANTIZATIONINFO_AFFINEPARAMS.containing_type = _QUANTIZATIONINFO
_QUANTIZATIONINFO_PERAXISPARAMS.fields_by_name['min_max'].message_type = _QUANTIZATIONINFO_MINMAX
_QUANTIZATIONINFO_PERAXISPARAMS.fields_by_name['affine_params'].message_type = _QUANTIZATIONINFO_AFFINEPARAMS
_QUANTIZATIONINFO_PERAXISPARAMS.containing_type = _QUANTIZATIONINFO
_QUANTIZATIONINFO_PERAXISPARAMS.oneofs_by_name['params_oneof'].fields.append(_QUANTIZATIONINFO_PERAXISPARAMS.fields_by_name['min_max'])
_QUANTIZATIONINFO_PERAXISPARAMS.fields_by_name['min_max'].containing_oneof = _QUANTIZATIONINFO_PERAXISPARAMS.oneofs_by_name['params_oneof']
_QUANTIZATIONINFO_PERAXISPARAMS.oneofs_by_name['params_oneof'].fields.append(_QUANTIZATIONINFO_PERAXISPARAMS.fields_by_name['affine_params'])
_QUANTIZATIONINFO_PERAXISPARAMS.fields_by_name['affine_params'].containing_oneof = _QUANTIZATIONINFO_PERAXISPARAMS.oneofs_by_name['params_oneof']
_QUANTIZATIONINFO_METADATA.containing_type = _QUANTIZATIONINFO
_QUANTIZATIONINFO_QUANTPARAMS.fields_by_name['params'].message_type = _QUANTIZATIONINFO_PERAXISPARAMS
_QUANTIZATIONINFO_QUANTPARAMS.fields_by_name['meta'].message_type = _QUANTIZATIONINFO_METADATA
_QUANTIZATIONINFO_QUANTPARAMS.containing_type = _QUANTIZATIONINFO
_QUANTIZATIONINFO_QUANTPARAMS.oneofs_by_name['name_oneof'].fields.append(_QUANTIZATIONINFO_QUANTPARAMS.fields_by_name['name'])
_QUANTIZATIONINFO_QUANTPARAMS.fields_by_name['name'].containing_oneof = _QUANTIZATIONINFO_QUANTPARAMS.oneofs_by_name['name_oneof']
_QUANTIZATIONINFO_QUANTPARAMS.oneofs_by_name['name_oneof'].fields.append(_QUANTIZATIONINFO_QUANTPARAMS.fields_by_name['name_regex'])
_QUANTIZATIONINFO_QUANTPARAMS.fields_by_name['name_regex'].containing_oneof = _QUANTIZATIONINFO_QUANTPARAMS.oneofs_by_name['name_oneof']
_QUANTIZATIONINFO.fields_by_name['entries'].message_type = _QUANTIZATIONINFO_QUANTPARAMS
DESCRIPTOR.message_types_by_name['QuantizationInfo'] = _QUANTIZATIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
QuantizationInfo = _reflection.GeneratedProtocolMessageType('QuantizationInfo', (_message.Message,), {'MinMax': _reflection.GeneratedProtocolMessageType('MinMax', (_message.Message,), {'DESCRIPTOR': _QUANTIZATIONINFO_MINMAX, '__module__': 'tensorflow.compiler.mlir.lite.quantization.quantization_info_pb2'}), 'AffineParams': _reflection.GeneratedProtocolMessageType('AffineParams', (_message.Message,), {'DESCRIPTOR': _QUANTIZATIONINFO_AFFINEPARAMS, '__module__': 'tensorflow.compiler.mlir.lite.quantization.quantization_info_pb2'}), 'PerAxisParams': _reflection.GeneratedProtocolMessageType('PerAxisParams', (_message.Message,), {'DESCRIPTOR': _QUANTIZATIONINFO_PERAXISPARAMS, '__module__': 'tensorflow.compiler.mlir.lite.quantization.quantization_info_pb2'}), 'Metadata': _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {'DESCRIPTOR': _QUANTIZATIONINFO_METADATA, '__module__': 'tensorflow.compiler.mlir.lite.quantization.quantization_info_pb2'}), 'QuantParams': _reflection.GeneratedProtocolMessageType('QuantParams', (_message.Message,), {'DESCRIPTOR': _QUANTIZATIONINFO_QUANTPARAMS, '__module__': 'tensorflow.compiler.mlir.lite.quantization.quantization_info_pb2'}), 'DESCRIPTOR': _QUANTIZATIONINFO, '__module__': 'tensorflow.compiler.mlir.lite.quantization.quantization_info_pb2'})
_sym_db.RegisterMessage(QuantizationInfo)
_sym_db.RegisterMessage(QuantizationInfo.MinMax)
_sym_db.RegisterMessage(QuantizationInfo.AffineParams)
_sym_db.RegisterMessage(QuantizationInfo.PerAxisParams)
_sym_db.RegisterMessage(QuantizationInfo.Metadata)
_sym_db.RegisterMessage(QuantizationInfo.QuantParams)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import tensor_slice_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
from ....tensorflow.core.framework import versions_pb2 as tensorflow_dot_core_dot_framework_dot_versions__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tensor_bundle.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x13org.tensorflow.utilB\x12TensorBundleProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n,tensorflow/core/protobuf/tensor_bundle.proto\x12\ntensorflow\x1a,tensorflow/core/framework/tensor_shape.proto\x1a,tensorflow/core/framework/tensor_slice.proto\x1a%tensorflow/core/framework/types.proto\x1a(tensorflow/core/framework/versions.proto"\xb1\x01\n\x11BundleHeaderProto\x12\x12\n\nnum_shards\x18\x01 \x01(\x05\x12<\n\nendianness\x18\x02 \x01(\x0e2(.tensorflow.BundleHeaderProto.Endianness\x12\'\n\x07version\x18\x03 \x01(\x0b2\x16.tensorflow.VersionDef"!\n\nEndianness\x12\n\n\x06LITTLE\x10\x00\x12\x07\n\x03BIG\x10\x01"\xd2\x01\n\x10BundleEntryProto\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x10\n\x08shard_id\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\x04 \x01(\x03\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x0e\n\x06crc32c\x18\x06 \x01(\x07\x12,\n\x06slices\x18\x07 \x03(\x0b2\x1c.tensorflow.TensorSliceProtoB\x85\x01\n\x13org.tensorflow.utilB\x12TensorBundleProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_versions__pb2.DESCRIPTOR])
_BUNDLEHEADERPROTO_ENDIANNESS = _descriptor.EnumDescriptor(name='Endianness', full_name='tensorflow.BundleHeaderProto.Endianness', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='LITTLE', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BIG', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=378, serialized_end=411)
_sym_db.RegisterEnumDescriptor(_BUNDLEHEADERPROTO_ENDIANNESS)
_BUNDLEHEADERPROTO = _descriptor.Descriptor(name='BundleHeaderProto', full_name='tensorflow.BundleHeaderProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_shards', full_name='tensorflow.BundleHeaderProto.num_shards', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='endianness', full_name='tensorflow.BundleHeaderProto.endianness', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version', full_name='tensorflow.BundleHeaderProto.version', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_BUNDLEHEADERPROTO_ENDIANNESS], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=234, serialized_end=411)
_BUNDLEENTRYPROTO = _descriptor.Descriptor(name='BundleEntryProto', full_name='tensorflow.BundleEntryProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.BundleEntryProto.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.BundleEntryProto.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shard_id', full_name='tensorflow.BundleEntryProto.shard_id', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='offset', full_name='tensorflow.BundleEntryProto.offset', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='size', full_name='tensorflow.BundleEntryProto.size', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='crc32c', full_name='tensorflow.BundleEntryProto.crc32c', index=5, number=6, type=7, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slices', full_name='tensorflow.BundleEntryProto.slices', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=414, serialized_end=624)
_BUNDLEHEADERPROTO.fields_by_name['endianness'].enum_type = _BUNDLEHEADERPROTO_ENDIANNESS
_BUNDLEHEADERPROTO.fields_by_name['version'].message_type = tensorflow_dot_core_dot_framework_dot_versions__pb2._VERSIONDEF
_BUNDLEHEADERPROTO_ENDIANNESS.containing_type = _BUNDLEHEADERPROTO
_BUNDLEENTRYPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_BUNDLEENTRYPROTO.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_BUNDLEENTRYPROTO.fields_by_name['slices'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__slice__pb2._TENSORSLICEPROTO
DESCRIPTOR.message_types_by_name['BundleHeaderProto'] = _BUNDLEHEADERPROTO
DESCRIPTOR.message_types_by_name['BundleEntryProto'] = _BUNDLEENTRYPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
BundleHeaderProto = _reflection.GeneratedProtocolMessageType('BundleHeaderProto', (_message.Message,), {'DESCRIPTOR': _BUNDLEHEADERPROTO, '__module__': 'tensorflow.core.protobuf.tensor_bundle_pb2'})
_sym_db.RegisterMessage(BundleHeaderProto)
BundleEntryProto = _reflection.GeneratedProtocolMessageType('BundleEntryProto', (_message.Message,), {'DESCRIPTOR': _BUNDLEENTRYPROTO, '__module__': 'tensorflow.core.protobuf.tensor_bundle_pb2'})
_sym_db.RegisterMessage(BundleEntryProto)
DESCRIPTOR._options = None
